.. _refman_ext_benchmark:

BenchMark
=========

This section contains source code documentation of Benchmark extension.

.. _refman_ext_benchmark_benchmark:

benchmark
^^^^^^^^^

.. automodule:: hydratk.extensions.benchmark.benchmark
   :member-order: bysource

